@@ -1,6 +1,4 @@
-"""
-Unit tests for KASKeyCache.
-"""
+"""Unit tests for KASKeyCache."""
 
 from dataclasses import dataclass
 
@@ -9,6 +7,8 @@ from otdf_python.kas_key_cache import KASKeyCache
 
 @dataclass
 class MockKasInfo:
+    """Mock KAS info for testing."""
+
     url: str
     algorithm: str | None = None
     public_key: str | None = None
@@ -17,6 +17,7 @@ class MockKasInfo:
 
 
 def test_kas_key_cache_set_and_get():
+    """Test KASKeyCache set and get operations."""
     cache = KASKeyCache()
     # Use the new store/get interface
     kas_info = MockKasInfo(url="http://example.com")
@@ -25,6 +26,7 @@ def test_kas_key_cache_set_and_get():
 
 
 def test_kas_key_cache_overwrite():
+    """Test KASKeyCache overwriting cached values."""
     cache = KASKeyCache()
     # Test overwriting with new values
     kas_info1 = MockKasInfo(url="http://example.com")
@@ -38,6 +40,7 @@ def test_kas_key_cache_overwrite():
 
 
 def test_kas_key_cache_clear():
+    """Test KASKeyCache clear operation."""
     cache = KASKeyCache()
     cache.set("key1", "value1")
     cache.clear()
