@@ -1,19 +1,22 @@
-"""
-Basic tests for the Python SDK class port.
-"""
+"""Basic tests for the Python SDK class."""
 
 from otdf_python.sdk import SDK
 
 
 class DummyServices(SDK.Services):
+    """Dummy SDK services for testing."""
+
     def close(self):
+        """Close the services."""
         self.closed = True
 
     def __exit__(self, exc_type, exc_val, exc_tb):
+        """Exit context manager."""
         pass
 
 
 def test_sdk_init_and_close():
+    """Test SDK initialization and close."""
     services = DummyServices()
     sdk = SDK(services)
     assert sdk.get_services() is services
@@ -25,6 +28,7 @@ def test_sdk_init_and_close():
 
 
 def test_split_key_exception():
+    """Test SDK SplitKeyException."""
     try:
         raise SDK.SplitKeyException("split key error")
     except SDK.SplitKeyException:
@@ -32,6 +36,7 @@ def test_split_key_exception():
 
 
 def test_data_size_not_supported():
+    """Test SDK DataSizeNotSupported exception."""
     try:
         raise SDK.DataSizeNotSupported("too large")
     except SDK.DataSizeNotSupported:
@@ -39,6 +44,7 @@ def test_data_size_not_supported():
 
 
 def test_kas_info_missing():
+    """Test SDK KasInfoMissing exception."""
     try:
         raise SDK.KasInfoMissing("kas info missing")
     except SDK.KasInfoMissing:
@@ -46,6 +52,7 @@ def test_kas_info_missing():
 
 
 def test_kas_public_key_missing():
+    """Test SDK KasPublicKeyMissing exception."""
     try:
         raise SDK.KasPublicKeyMissing("kas pubkey missing")
     except SDK.KasPublicKeyMissing:
@@ -53,6 +60,7 @@ def test_kas_public_key_missing():
 
 
 def test_tamper_exception():
+    """Test SDK TamperException."""
     try:
         raise SDK.TamperException("tamper")
     except SDK.TamperException:
@@ -60,6 +68,7 @@ def test_tamper_exception():
 
 
 def test_root_signature_validation_exception():
+    """Test SDK RootSignatureValidationException."""
     try:
         raise SDK.RootSignatureValidationException("root sig")
     except SDK.RootSignatureValidationException:
@@ -67,6 +76,7 @@ def test_root_signature_validation_exception():
 
 
 def test_segment_signature_mismatch():
+    """Test SDK SegmentSignatureMismatch exception."""
     try:
         raise SDK.SegmentSignatureMismatch("seg sig")
     except SDK.SegmentSignatureMismatch:
@@ -74,6 +84,7 @@ def test_segment_signature_mismatch():
 
 
 def test_kas_bad_request_exception():
+    """Test SDK KasBadRequestException."""
     try:
         raise SDK.KasBadRequestException("kas bad req")
     except SDK.KasBadRequestException:
@@ -81,6 +92,7 @@ def test_kas_bad_request_exception():
 
 
 def test_kas_allowlist_exception():
+    """Test SDK KasAllowlistException."""
     try:
         raise SDK.KasAllowlistException("kas allowlist")
     except SDK.KasAllowlistException:
@@ -88,6 +100,7 @@ def test_kas_allowlist_exception():
 
 
 def test_assertion_exception():
+    """Test SDK AssertionException."""
     try:
         raise SDK.AssertionException("assertion", "id123")
     except SDK.AssertionException:
